@@ -1,13 +1,13 @@
 package CGI::Easy::URLconf;
-
+use 5.010001;
 use warnings;
 use strict;
+use utf8;
 use Carp;
 
-use version; our $VERSION = qv('1.0.1');    # REMINDER: update Changes
+our $VERSION = 'v2.0.0';
 
-# REMINDER: update dependencies in Makefile.PL
-use Perl6::Export::Attrs;
+use Export::Attrs;
 use URI::Escape qw( uri_escape_utf8 );
 
 
@@ -128,8 +128,11 @@ sub view2path :Export {
             if (@{$values} != ($tmpl =~ tr/?//)) {
                 croak "incorrect values amount for template '$tmpl'";
             }
-            # WARNING apache не разрешает %2F в пути (nginx разрешает)
-            $_ = uri_escape_utf8($_), s/%2F/\//g for @{$values};    ## no critic
+            # WARNING apache doesn't allow %2F in path (nginx allow)
+            for (@{$values}) {
+                $_ = uri_escape_utf8($_);
+                s/%2F/\//msg;
+            }
             $tmpl =~ s/[?]/shift @{$values}/xmsge;
             $path = $tmpl;
             last;
@@ -158,7 +161,9 @@ sub with_params :Export {
             return if !defined $p->{ $name };
             push @values, $p->{ $name };
         }
-        delete $p->{$_} for @names; ## no critic
+        for (@names) {
+            delete $p->{$_};
+        }
         return \@values;
     };
 }
@@ -174,6 +179,11 @@ __END__
 CGI::Easy::URLconf - map url path to handler sub and vice versa
 
 
+=head1 VERSION
+
+This document describes CGI::Easy::URLconf version v2.0.0
+
+
 =head1 SYNOPSIS
 
     use CGI::Easy::URLconf qw( setup_path path2view set_param );
@@ -428,71 +438,63 @@ Return CALLBACK subroutine suitable for using in setup_view().
 =back
 
 
-=head1 BUGS AND LIMITATIONS
-
-No bugs have been reported.
-
-
 =head1 SUPPORT
 
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CGI-Easy-URLconf>.
-I will be notified, and then you'll automatically be notified of progress
-on your bug as I make changes.
+=head2 Bugs / Feature Requests
 
-You can also look for information at:
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/powerman/perl-CGI-Easy-URLconf/issues>.
+You will be notified automatically of any progress on your issue.
+
+=head2 Source Code
+
+This is open source software. The code repository is available for
+public review and contribution under the terms of the license.
+Feel free to fork the repository and submit pull requests.
+
+L<https://github.com/powerman/perl-CGI-Easy-URLconf>
+
+    git clone https://github.com/powerman/perl-CGI-Easy-URLconf.git
+
+=head2 Resources
 
 =over
 
-=item * RT: CPAN's request tracker
+=item * MetaCPAN Search
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=CGI-Easy-URLconf>
+L<https://metacpan.org/search?q=CGI-Easy-URLconf>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/dist/CGI-Easy-URLconf>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/CGI-Easy-URLconf>
 
-=item * CPAN Ratings
+=item * CPAN Testers Matrix
 
-L<http://cpanratings.perl.org/d/CGI-Easy-URLconf>
+L<http://matrix.cpantesters.org/?dist=CGI-Easy-URLconf>
 
-=item * Search CPAN
+=item * CPANTS: A CPAN Testing Service (Kwalitee)
 
-L<http://search.cpan.org/dist/CGI-Easy-URLconf/>
+L<http://cpants.cpanauthors.org/dist/CGI-Easy-URLconf>
 
 =back
 
 
 =head1 AUTHOR
 
-Alex Efros  C<< <powerman-asdf@ya.ru> >>
+Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Alex Efros <powerman-asdf@ya.ru>.
+This software is Copyright (c) 2009-2010 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
-This program is distributed under the MIT (X11) License:
-L<http://www.opensource.org/licenses/mit-license.php>
+This is free software, licensed under:
 
-Permission is hereby granted, free of charge, to any person
-obtaining a copy of this software and associated documentation
-files (the "Software"), to deal in the Software without
-restriction, including without limitation the rights to use,
-copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following
-conditions:
+  The MIT (X11) License
 
-The above copyright notice and this permission notice shall be
-included in all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-OTHER DEALINGS IN THE SOFTWARE.
 
+=cut
